@@ -40,7 +40,12 @@ def run_subprocess(
     @wraps(func)
     @click.make_pass_decorator(GlobalOptions)
     def impl(
-        options: GlobalOptions, *args: Any, capture_output_=False, **kwargs: Any
+        options: GlobalOptions,
+        *args: Any,
+        capture_output_=False,
+        silence_stderr_=True,
+        input_=None,
+        **kwargs: Any,
     ) -> Optional[Sequence[Optional[str]]]:
         outputs = []
         for command in func(*args, **kwargs):
@@ -51,7 +56,8 @@ def run_subprocess(
                 command,
                 check=True,
                 capture_output=capture_output_,
-                stderr=None if capture_output_ else PIPE,
+                input=input_,
+                stderr=None if (capture_output_ or not silence_stderr_) else PIPE,
                 text=True,
             )
             outputs.append(result.stdout)
@@ -72,7 +78,7 @@ def intercept_errors(
             try:
                 return fn(*args, **kwargs)
             except CalledProcessError as err:
-                message = err.stderr
+                message = err.stderr or ""
                 raise_if_match(patterns, message)
                 if not (quiet or quiet_):
                     sys.stderr.write(message)
@@ -116,6 +122,19 @@ def require_login(fn: F) -> F:
     return cast(F, wrapped)
 
 
+def loses_interactivity(fn: F) -> F:
+    @click.pass_context
+    @wraps(fn)
+    def wrapped(context: click.Context, *args: Any, **kwargs: Any) -> Any:
+        if (resource := kwargs.get("resource")) :
+            context.find_object(GlobalOptions).create_saml_client(
+                resource
+            ).ensure_session()
+        return context.invoke(fn, *args, **kwargs)
+
+    return cast(F, require_login(wrapped))
+
+
 def setup_segment(**kwargs: Any) -> Callable[[F], F]:
     analytics.default_client = analytics.client.Client(send=ProdMode, **kwargs)
 
