@@ -4,12 +4,13 @@ from pathlib import Path
 from typing import Final, Iterator, Tuple
 
 from ..decorators import intercept_errors, require_bins, run_subprocess
+from ..helpers.boto import get_identity
 from ..helpers.contexts import push_env
 from ..helpers.keywords_to_options import Argument
 from ..helpers.params import Profile
 from .saml_client import SAMLClient
 
-AwsCredentialsPath = Path(os.getenv('AWS_CONFIG_FILE', Path.home() / '.aws' / 'credentials'))
+AwsCredentialsPath = Path(os.getenv('AWS_CREDENTIAL_FILE', Path.home() / '.aws' / 'credentials'))
 
 class AwsProfile(SAMLClient):
     binary = "aws"
@@ -49,4 +50,4 @@ class AwsProfile(SAMLClient):
         return ConfigParser()
 
     def _ensure_session(self):
-        pass
+        get_identity(self)
