@@ -25,6 +25,15 @@ def test_saml2aws(
     )
 
 
+def test_saml2aws_get_creds(
+    test_context: TestContextFixture[Saml2Aws], capture_command: CaptureCommand
+) -> None:
+    capture_command.enqueue_outputs("", "AWS_REGION=foobar\nAWS_FOOBAR=baz")
+    with test_context(debug=False) as saml2aws:
+        with capture_command():
+            assert saml2aws.get_creds() == {"AWS_REGION": "foobar"}
+
+
 def test_saml2aws_debug(
     test_context: TestContextFixture[Saml2Aws], capture_command: CaptureCommand
 ) -> None:
